==> db4o_7.4.121.14026+dfsg.orig.tar.gz: db4o-7.4.121.14026+dfsg/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Soda/Arrays/AllTests.cs <==
/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2009  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using System;
using Db4oUnit.Extensions;
using Db4objects.Db4o.Tests.Common.Soda.Arrays.Object;
using Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed;
using Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped;

namespace Db4objects.Db4o.Tests.Common.Soda.Arrays
{
	public class AllTests : Db4oTestSuite
	{
		protected override Type[] TestCases()
		{
			return new Type[] { typeof(STArrMixedTestCase), typeof(STArrStringOTestCase), typeof(
				STArrStringONTestCase), typeof(STArrStringTTestCase), typeof(STArrStringTNTestCase
				), typeof(STArrStringUTestCase), typeof(STArrStringUNTestCase), typeof(STArrIntegerOTestCase
				), typeof(STArrIntegerONTestCase), typeof(STArrIntegerTTestCase), typeof(STArrIntegerTNTestCase
				), typeof(STArrIntegerUTestCase), typeof(STArrIntegerUNTestCase), typeof(STArrIntegerWTTestCase
				), typeof(STArrIntegerWTONTestCase), typeof(STArrIntegerWUONTestCase) };
		}
	}
}

==> db4o_8.0.184.15484+dfsg2.orig.tar.gz: db4o-8.0.184.15484+dfsg/src/Db4objects.Db4o.Tests/Db4objects.Db4o.Tests/Common/Soda/Arrays/AllTests.cs <==
/* This file is part of the db4o object database http://www.db4o.com

Copyright (C) 2004 - 2010  Versant Corporation http://www.versant.com

db4o is free software; you can redistribute it and/or modify it under
the terms of version 3 of the GNU General Public License as published
by the Free Software Foundation.

db4o is distributed in the hope that it will be useful, but WITHOUT ANY
WARRANTY; without even the implied warranty of MERCHANTABILITY or
FITNESS FOR A PARTICULAR PURPOSE.  See the GNU General Public License
for more details.

You should have received a copy of the GNU General Public License along
with this program.  If not, see http://www.gnu.org/licenses/. */
using System;
using Db4oUnit.Extensions;
using Db4objects.Db4o.Tests.Common.Soda.Arrays;
using Db4objects.Db4o.Tests.Common.Soda.Arrays.Object;
using Db4objects.Db4o.Tests.Common.Soda.Arrays.Typed;
using Db4objects.Db4o.Tests.Common.Soda.Arrays.Untyped;

namespace Db4objects.Db4o.Tests.Common.Soda.Arrays
{
	public class AllTests : Db4oTestSuite
	{
		protected override Type[] TestCases()
		{
			return new Type[] { typeof(STArrMixedTestCase), typeof(STArrStringOTestCase), typeof(
				STArrStringONTestCase), typeof(STArrStringTTestCase), typeof(STArrStringTNTestCase
				), typeof(STArrStringUTestCase), typeof(STArrStringUNTestCase), typeof(STArrIntegerOTestCase
				), typeof(STArrIntegerONTestCase), typeof(STArrIntegerTTestCase), typeof(STArrIntegerTNTestCase
				), typeof(STArrIntegerUTestCase), typeof(STArrIntegerUNTestCase), typeof(STArrIntegerWTTestCase
				), typeof(STArrIntegerWTONTestCase), typeof(STArrIntegerWUONTestCase), typeof(ArrayDescendSubQueryTestCase
				) };
		}
	}
}
